import { compact } from '../../util/array.js';
import { getPackageName } from '../../util/modules.js';
import { resolvePluginPackageName, getDependenciesFromSettings } from './helpers.js';
export const fallback = async (configFilePath, { cwd }) => {
    const { ESLint } = await import('eslint');
    const engine = new ESLint({ cwd, overrideConfigFile: configFilePath, useEslintrc: false });
    const jsConfig = await engine.calculateConfigForFile('__placeholder__.js');
    const tsConfig = await engine.calculateConfigForFile('__placeholder__.ts');
    const tsxConfig = await engine.calculateConfigForFile('__placeholder__.tsx');
    const dependencies = [jsConfig, tsConfig, tsxConfig].map(config => {
        if (!config)
            return [];
        const plugins = config.plugins?.map(resolvePluginPackageName) ?? [];
        const parsers = config.parser ? [config.parser] : [];
        const extraParsers = config.parserOptions?.babelOptions?.presets ?? [];
        const settings = config.settings ? getDependenciesFromSettings(config.settings) : [];
        return [...parsers, ...extraParsers, ...plugins, ...settings].map(getPackageName);
    });
    return compact(dependencies.flat());
};
