import util from 'node:util';
import parsedArgs from './cli-arguments.js';
const { debug, 'debug-file-filter': debugFileFilter } = parsedArgs.values;
const IS_ENABLED = debug ?? false;
const FILE_FILTER = debugFileFilter;
const inspectOptions = { maxArrayLength: null, depth: null, colors: true };
const logArray = (collection) => console.log(util.inspect(collection.sort(), inspectOptions));
export const debugLogObject = (name, obj) => {
    if (!IS_ENABLED)
        return;
    console.log(`[knip] ${name}`);
    console.log(util.inspect(obj, inspectOptions));
};
export const debugLogFiles = (name, filePaths) => {
    if (!IS_ENABLED)
        return;
    const size = Array.isArray(filePaths) ? filePaths.length : filePaths.size;
    console.debug(`[knip] ${name} (${size})`);
    if (FILE_FILTER) {
        const fileFilter = new RegExp(FILE_FILTER);
        logArray(Array.from(filePaths).filter(filePath => fileFilter.test(filePath)));
    }
    else {
        logArray(Array.from(filePaths));
    }
};
export const debugLogSourceFiles = (name, sourceFiles) => {
    if (!IS_ENABLED)
        return;
    const size = Array.isArray(sourceFiles) ? sourceFiles.length : sourceFiles.size;
    console.debug(`[knip] ${name} (${size})`);
    if (FILE_FILTER) {
        const fileFilter = new RegExp(FILE_FILTER);
        const files = Array.from(sourceFiles)
            .map(sourceFile => sourceFile.getFilePath())
            .filter(filePath => fileFilter.test(filePath));
        logArray(files);
    }
    else {
        const files = Array.from(sourceFiles).map(sourceFile => sourceFile.getFilePath());
        logArray(files);
    }
};
